@@ -1,34 +1,12 @@
 package WWW::Scraper::ISBN;
 
-use 5.008;
 use strict;
 use warnings;
 
 use WWW::Scraper::ISBN::Record;
 use Carp;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use WWW::Scraper::ISBN ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 
 # Preloaded methods go here.
@@ -207,6 +185,8 @@ search was successful.
 
 No mailing list or website currently available.  Primary development done through CSX ( L<http://csx.calvin.edu/> )
 
+=back
+
 =head1 AUTHOR
 
 Andy Schamp, E<lt>andy@schamp.netE<gt>
